#ifndef _lgamma_mvC_H
#define _lgamma_mvC_H

#include <Rcpp.h>

using namespace Rcpp;

double lgamma_mvC(const double & x, const double & p);

#endif
